===================
Welcome to wildboar
===================

Wildboar is a package for supervised and unsupervised machine learning for time
series data.

.. toctree::
   :hidden:
   :maxdepth: 3

   install
   tutorial
   guide
   examples
   API Reference <wildboar/index>

.. panels::

   Classification
   ^^^^^^^^^^^^^^

   Identifying which category a time series belong to.

   **Algorithms**: Random shapelet forest and Extra shapelet trees

   ---

   Regression
   ^^^^^^^^^^

   Predicting a continuous-valued attribute associated with a time series.

   **Algorithms**: Random shapelet forest and Extra shapelet trees 

   ---

   Counterfactuals
   ^^^^^^^^^^^^^^^

   Explaining time series classifiers by counterfactual reasoning.

   **Algorithms**: Shapelet forest counterfactuals, KNearest counterfactuals and
   Prototype counterfactuals
